@@ -1055,13 +1055,12 @@ std::string socket_base::address_to_string(sockaddr const* addr, int addr_len, b
 				return {};
 		}
 	}
-	int res = getnameinfo(addr, addr_len, hostbuf, NI_MAXHOST, portbuf, NI_MAXSERV, NI_NUMERICHOST | NI_NUMERICSERV);
+	int res = getnameinfo(addr, addr_len, hostbuf, NI_MAXHOST, with_port ? portbuf : nullptr, with_port ? NI_MAXSERV : 0, NI_NUMERICHOST | NI_NUMERICSERV);
 	if (res) { // Should never fail
 		return std::string();
 	}
 
 	std::string host = hostbuf;
-	std::string port = portbuf;
 
 	// IPv6 uses colons as separator, need to enclose address
 	// to avoid ambiguity if also showing port
@@ -1078,7 +1077,7 @@ std::string socket_base::address_to_string(sockaddr const* addr, int addr_len, b
 	}
 
 	if (with_port) {
-		return host + ":" + port;
+		return host + ":" + std::string(portbuf);
 	}
 	else {
 		return host;
@@ -1091,7 +1090,7 @@ std::string socket_base::address_to_string(char const* buf, int buf_len)
 		return std::string();
 	}
 
-	sockaddr_u addr;
+	sockaddr_u addr{};
 	if (buf_len == 16) {
 		memcpy(&addr.in6.sin6_addr, buf, buf_len);
 		addr.in6.sin6_family = AF_INET6;
